# Copyright 2021 The Kubeflow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Google Cloud Pipeline Experimental Forecasting Components."""

import os
from typing import Optional

from google.cloud import aiplatform as aiplatform_sdk
from google_cloud_pipeline_components.aiplatform import utils
from kfp.components import load_component_from_file

__all__ = [
    'ForecastingPreprocessingOp',
    'ForecastingValidationOp',
    'ForecastingPrepareDataForTrainOp',
    'ForecastingTrainingWithExperimentsOp',
]

ForecastingPreprocessingOp = load_component_from_file(
        os.path.join(os.path.dirname(__file__), 'preprocess/component.yaml'))

ForecastingValidationOp = load_component_from_file(
        os.path.join(os.path.dirname(__file__), 'validate/component.yaml'))

ForecastingPrepareDataForTrainOp = load_component_from_file(
        os.path.join(os.path.dirname(__file__), 'prepare_data_for_train/component.yaml'))

ForecastingTrainingWithExperimentsOp = utils.convert_method_to_component(
    aiplatform_sdk.AutoMLForecastingTrainingJob,
    aiplatform_sdk.AutoMLForecastingTrainingJob._run_with_experiments,
)
